@@ -1,6 +1,6 @@
 ;;; xcb-types.el --- Type definitions for XCB  -*- lexical-binding: t -*-
 
-;; Copyright (C) 2015-2024 Free Software Foundation, Inc.
+;; Copyright (C) 2015-2025 Free Software Foundation, Inc.
 
 ;; Author: Chris Feng <chris.w.feng@gmail.com>
 
@@ -54,6 +54,17 @@
 (require 'eieio)
 (require 'xcb-debug)
 
+;; We can't require `xcb-xkb' because it requires us.
+(eieio-declare-slots xkbType)
+;; We can't require `xcb-preset' because it requires us.
+(eieio-declare-slots extension) ;; xcb:preset:Generic
+;; We can't require `xcb-present' because it requires us.
+(eieio-declare-slots ~sequence evtype) ;xcb:present:Generic
+
+;; Require subr-x on Emacs < 29 for when-let*, it has since been moved to
+;; subr (autoloaded).
+(eval-when-compile (when (< emacs-major-version 29) (require 'subr-x)))
+
 (define-minor-mode xcb:debug
   "Debug-logging enabled if non-nil."
   :group 'debug
@@ -487,7 +498,7 @@ Consider let-bind it rather than change its global value."))
   (unless (eq fn #'oref-default)
     (xcb:-log "unbound-slot: %s" (list (eieio-class-name class)
                                        (eieio-object-name object)
-			               slot-name fn))))
+                                       slot-name fn))))
 
 (defclass xcb:-struct (xcb:--struct)
   ((~lsb :initarg :~lsb
@@ -577,10 +588,10 @@ The optional POS argument indicates current byte index of the field (used by
        ;; to be converted to a vector of bytes, then the transform can
        ;; be done trivially and much faster by just coercing.
        (if (and (eq list-type 'xcb:BYTE)
-		(eq (type-of data) 'string))
-	   (cl-coerce data 'vector)
-	 (mapconcat (lambda (i) (xcb:-marshal-field obj list-type i))
-		    data []))))
+                (eq (type-of data) 'string))
+           (cl-coerce data 'vector)
+         (mapconcat (lambda (i) (xcb:-marshal-field obj list-type i))
+                    data []))))
     (`xcb:-switch
      (let ((slots (eieio-class-slots (eieio-object-class obj)))
            (expression (plist-get value 'expression))
@@ -827,7 +838,7 @@ This method auto-pads short results to 32 bytes."
           ;; XKB event.
           (setf (slot-value obj 'xkbType) (aref event-number 0))
         ;; Generic event.
-        (setf (slot-value obj 'extensions) (aref event-number 0)
+        (setf (slot-value obj 'extension) (aref event-number 0)
               (slot-value obj 'evtype) (aref event-number 1))))
     (when (slot-exists-p obj '~sequence)
       (setf (slot-value obj '~sequence) (or sequence 0)))
